@@ -1,8 +1,9 @@
 import click
 
-from ..decorators import require_login
-from ..helpers.config import Config
-from ..helpers.params import get_profiles
+from sym.cli.decorators import require_login
+from sym.cli.helpers.config import Config
+from sym.cli.helpers.params import get_profiles
+
 from .sym import sym
 
 
