@@ -3,15 +3,15 @@ import sys
 from typing import Dict, Optional, Sequence
 
 import click
+from sym.shared.cli.helpers.keywords_to_options import keywords_to_options
 
+from sym.cli.decorators import command_require_bins, loses_interactivity, require_login
 from sym.cli.helpers.ec2.factory import get_ec2_client
+from sym.cli.helpers.global_options import GlobalOptions
+from sym.cli.saml_clients.saml_client_factory import SAMLClientFactory
 
-from ..decorators import command_require_bins, loses_interactivity, require_login
-from ..helpers.global_options import GlobalOptions
-from ..helpers.keywords_to_options import keywords_to_options
 from ..helpers.options import resource_argument
 from ..helpers.ssh import raw_ssh, start_interactive_command, start_ssh_session
-from ..saml_clients.saml_client_factory import SAMLClientFactory
 from .sym import sym
 
 SSH_MAN = """
@@ -187,6 +187,7 @@ def use_interactive_ssm(is_a_tty: bool, command: Sequence[str], args: Dict) -> b
 )
 @resource_argument
 @click.option("-p", "--port", default=22, type=int, show_default=True)
+@click.option("--force-ssh/--no-force-ssh", default=False)
 @click.argument("destination", required=False)
 @click.argument("command", nargs=-1, required=False)
 @ssh_options
@@ -198,6 +199,7 @@ def ssh(
     options: GlobalOptions,
     resource: str,
     destination: Optional[str],
+    force_ssh: bool,
     port: int,
     command: Sequence[str],
     **kwargs,
@@ -232,10 +234,13 @@ def ssh(
     instance = get_ec2_client(client).load_instance_by_alias(destination)
     new_client = SAMLClientFactory.clone(client, aws_region=instance.region)
 
-    interactive_ssm = use_interactive_ssm(
-        is_a_tty=sys.stdin.isatty(),
-        command=command,
-        args=kwargs,
+    interactive_ssm = (
+        use_interactive_ssm(
+            is_a_tty=sys.stdin.isatty(),
+            command=command,
+            args=kwargs,
+        )
+        and not force_ssh
     )
 
     if interactive_ssm:
