@@ -1,6 +1,7 @@
 from contextlib import contextmanager
 from pathlib import Path
 from typing import Callable, ContextManager, Iterator
+from unittest.mock import patch
 
 import boto3
 import click
@@ -68,6 +69,13 @@ def no_click_setup(sandbox: Sandbox):
     return context
 
 
+@pytest.fixture(autouse=True)
+def global_mocks(request):
+    if "skip_global_mocks" not in request.keywords:
+        with patch("sym.cli.helpers.version.get_latest_version", return_value=None):
+            yield
+
+
 @pytest.fixture(autouse=True)
 def patch_is_setup(monkeypatch: MonkeyPatch):
     monkeypatch.setattr(SAMLClient, "check_is_setup", lambda self: ...)
